# binary4fun

binary4fun is a small game written in Python that can be played in the cli. The game basically tries to guess a number between 1 and 100 by binary search.

## Installation
### pip

You can install binary4fun from PyPI using pip:
```
pip install binary4fun
```

## Usage

To start the game, run the following in the command line:
```
python3 -m binary4fun
```

## Release History

* 0.1.0: First release

The package on PyPI: https://pypi.org/project/binary4fun

Distributed under the MIT license. See ``LICENSE`` for more information.